<?php

declare(strict_types=1);

namespace App\Controller;

use App\Form\BulkEditDrinkTypeStockForm;
use App\Repository\DrinkTypeRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/drink-types')]
final class DrinkTypeBulkController extends AbstractController
{
    #[Route('/bulk-edit-stock', name: 'app_drink_type_bulk_edit_stock')]
    public function bulkEditStock(
        Request $request,
        DrinkTypeRepository $drinkTypeRepository,
        EntityManagerInterface $entityManager
    ): Response {
        $drinkTypes = $drinkTypeRepository->findAll();

        $form = $this->createForm(BulkEditDrinkTypeStockForm::class, [
            'drinkTypes' => $drinkTypes,
        ]);

        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $data = $form->getData();

            foreach ($data['drinkTypes'] as $drinkType) {
                $entityManager->persist($drinkType);
            }

            $entityManager->flush();

            $this->addFlash('success', 'Wanted stock levels updated successfully!');

            return $this->redirectToRoute('app_drink_type_bulk_edit_stock');
        }

        return $this->render('drink_type/bulk_edit_stock.html.twig', [
            'form' => $form->createView(),
            'drinkTypes' => $drinkTypes,
        ]);
    }
}
